@@ -30,7 +30,9 @@ class H2OGBMClassifier(H2OGBM):
                  calibrationDataFrame=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -41,7 +43,6 @@ class H2OGBMClassifier(H2OGBM):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  learnRate=0.1,
                  learnRateAnnealing=1.0,
                  sampleRate=1.0,
@@ -92,12 +93,14 @@ class H2OGBMClassifier(H2OGBM):
                  gainsliftBins=-1,
                  customMetricFunc=None,
                  customDistributionFunc=None,
-                 exportCheckpointsDir=None):
+                 exportCheckpointsDir=None,
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2OGBM, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.classification.H2OGBMClassifier", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
